@@ -77,7 +77,7 @@ class Crash(checks.AgentCheck):
 
                     # Return the date-/timestamp of the most recent crash
                     if dump_count == 1:
-                        value_meta = {'latest': unicode(dt)}
+                        value_meta = {'latest': str(dt)}
 
         log.debug('dump_count: %s', dump_count)
         self.gauge('crash.dump_count', dump_count, dimensions=dimensions,
